/*-------------------------------------------------------------------
|                             SHOWWPG.H                              |
--------------------------------------------------------------------*/
/* Menu IDs. */
#define IDM_RETRIEVE      100
#define IDM_ABOUT         200
#define IDM_COPY          300

/* Initial position of window. */
#define INIT_POSX    45
#define INIT_POSY    45
#define INIT_WIDTH  582
#define INIT_HEIGHT 398

/* Largeset file possible. */
#define MAX_FILE_SIZE 32000L

/* Default size of WordPerfect Graphics space. */
#define DEFAULT_WPG_WIDTH  10800
#define DEFAULT_WPG_HEIGHT  7800

/* WPG record types (complete as of December 1993). */
#define WPG_FILLATTR     0x01
#define WPG_LINEATTR     0x02
#define WPG_MARKATTR     0x03
#define WPG_POLYMARKER   0x04
#define WPG_LINE         0x05
#define WPG_POLYLINE     0x06
#define WPG_RECTANGLE    0x07
#define WPG_POLYGON      0x08
#define WPG_ELLIPSE      0x09
#define WPG_RESERVED     0x0A
#define WPG_BITMAP1      0x0B
#define WPG_GRTXT1       0x0C
#define WPG_GRTXTATTR    0x0D
#define WPG_COLORMAP     0x0E
#define WPG_START1       0x0F
#define WPG_END          0x10
#define WPG_PS1          0x11
#define WPG_OUTATTR      0x12
#define WPG_CURVE        0x13
#define WPG_BITMAP2      0x14
#define WPG_STARTFIG     0x15
#define WPG_STARTCHART   0x16
#define WPG_PLANPERF     0x17
#define WPG_GRTXT2       0x18
#define WPG_START2       0x19
#define WPG_GRTXT3       0x1A
#define WPG_PS2          0x1B
#define WPG_FIRST        WPG_FILLATTR
#define WPG_LAST         WPG_PS2

/* Offsets into WPG file. */
#define WPG_OFFS_FIRSTREC  16
#define WPG_OFFS_WPGSIZE   20

/* System states in Modify(). */
#define WAITING             0
#define START_MODIFYING     1
#define MODIFYING           2

/* Initial margin percent for TargetRect used in InitScaleParms():
 * specifies percent of ClientRect to use as initial margin for
 * TargetRect. Keep in range 0.0 <= INIT_MARGIN <= 0.45.
 */
#define INIT_MARGIN 0.10

/* Number of modifications (8 resizes + translate). */
#define NUM_MODIFIES  9

/* Names for different modifications : TOP_LEFT for top left, TOP_MID for
 * top middle, etc. DON'T CHANGE -- used as array indices in HCursor[],
 * return values from PtinHotSpot(), and elsewhere.
 */
#define TOP_LEFT    0
#define TOP_MID     1
#define TOP_RT      2
#define MID_RT      3
#define BOT_RT      4
#define BOT_MID     5
#define BOT_LEFT    6
#define MID_LEFT    7
#define TRANSLATE   8
#define NO_HIT      9
#define WAIT       10

/* Identifiers in UpdateScale(); can't conflict with TOP_LEFT thru
 * TRANSLATE, otherwise arbitrary.
 */
#define ZOOM_IN    18
#define ZOOM_OUT   19

/* Percent increment applied to Scale on double-click zooms. */
#define SCALE_PERCENT 0.10

/* Constants for little black boxes : (BOXSIZE, MARGIN) are fundamental
 * constants and the others are calculated. The calculations would be built
 * into the #defines, except that hard-coding them like this saves repeated
 * calculations at run time.
 *   --------------------------------------------------
 *   | BOXSIZE = size of the little black boxes
 *   | MARGIN  = margin between little boxes and TargetRect
 *   | HALF_BOXSIZE  = (BOXSIZE - 1) / 2
 *   | HALF_BOXSIZE1 = HALF_BOXSIZE + 1
 *   | MARGIN1 = MARGIN + 1
 *   | BOXSIZE_PL_MARGIN  = BOXSIZE + MARGIN
 *   | BOXSIZE_PL_MARGIN1 = BOXSIZE + MARGIN + 1
 *   --------------------------------------------------
 * IF CHANGE BOXSIZE OR MARGIN, change 5 calculated constants appropriately.
 * BOXSIZE MUST BE ODD for symmetry.
 */
#define BOXSIZE        5
#define MARGIN         2
#define HALF_BOXSIZE   2
#define HALF_BOXSIZE1  3
#define MARGIN1        3
#define BOXSIZE_PL_MARGIN   7
#define BOXSIZE_PL_MARGIN1  8

/* Instruction line height, in pixels. */
#define ILINE_HT 14

/* Return values from FileRead(). */
#define SUCCESS            0
#define FILE_OPEN_FAILURE  1
#define FILE_TOO_LARGE     2
#define NOT_ENOUGH_MEMORY  3
#define FILE_READ_FAILURE  4
#define NOT_WPG_FILE       5

/* String ID for use with GetOpenFileName() (see RC). */
#define IDS_FILTERSTRING       200
/* String IDs for MessageBox() error report (see RC) -- keep in 300s. */
#define IDS_ERROR_BASE         300
#define IDS_FILE_OPEN_FAILURE  (IDS_ERROR_BASE + FILE_OPEN_FAILURE)
#define IDS_FILE_TOO_LARGE     (IDS_ERROR_BASE + FILE_TOO_LARGE)
#define IDS_NOT_ENOUGH_MEMORY  (IDS_ERROR_BASE + NOT_ENOUGH_MEMORY)
#define IDS_FILE_READ_FAILURE  (IDS_ERROR_BASE + FILE_READ_FAILURE)
#define IDS_NOT_WPG_FILE       (IDS_ERROR_BASE + NOT_WPG_FILE)
/* String ID for instruction line. */
#define IDS_INSTR              400

/* Constants for SetBrush() and SetPen(). */
#define SET_INIT 0
#define SET_MID  1
#define SET_END  2

/* WPG_FILLATTR fill patterns. */
#define FA_HOLLOW       0
#define FA_SOLID        1
#define FA_NARROW45     2
#define FA_UMBRELLA2   63
#define FA_BACKGROUND 255

/* WPG_LINEATTR line styles. */
#define LA_NOLINE 0

/* Absolute value macro for ints. */
#define ABS(x) (((x) < 0) ? (-(x)) : (x))

/* Degree to radians conversion factor = pi/180. */
#define DR 0.01745329252

/* Attributes for intrasegment functions. */
#define LOCAL NEAR PASCAL

/* Scale parameters. */
typedef struct
  {
  double scaleX;
  double scaleY;
  int    offsX;
  int    offsY;
  } SCALE;

typedef SCALE FAR* LPSCALE;

long WINAPI _export WndProc(HWND, UINT, UINT, LONG);
HANDLE LOCAL LoadWPGFile(HWND hWnd);
BOOL WINAPI _export AboutDlgProc(HWND, UINT, UINT, LONG);
void LOCAL PaintWindow(HDC hDC);
void LOCAL Modify(HWND hWnd, UINT message, LONG lParam);
long LOCAL FileLength(int hFile);
int LOCAL FileRead(LPSTR FileName, LPHANDLE lphMem);
BYTE LOCAL DrawWPGRecord(HDC hDC, LPBYTE FAR *p, SCALE sc);
DWORD LOCAL GetRecordLength(LPBYTE FAR *p);
void LOCAL SetBrush(HDC hDC, LPBYTE q, int when);
HBRUSH LOCAL MakePatternBrush(LPBYTE mp, int color);
void LOCAL SetPen(HDC hDC, LPBYTE q, int when);
void LOCAL DrawLine(HDC hDC, LPBYTE q, SCALE sc);
void LOCAL DrawPoly(HDC hDC, LPBYTE q, SCALE sc, BYTE rt);
void LOCAL DrawEllipse(HDC hDC, LPBYTE q, SCALE sc);
void LOCAL FrameOurRect(HDC hDC, LPRECT rp);
void LOCAL InitScaleParms(HANDLE hMem, LPSCALE lps, LPRECT lpr);
int  LOCAL PtinHotSpot(LPRECT lpr, POINT pt);
void LOCAL PlayWPGFile(HANDLE hb, HDC hDC, SCALE sc);
void LOCAL CopyWMFToClipBoard(HWND hWnd);
void LOCAL PaintInstructionLine(HDC hDC);
BOOL LOCAL OpenDlgBox(HWND hWnd, LPSTR szFile, WORD bufLen);
void LOCAL RestrictCursor(int type, HWND hWnd, LPPOINT lpp);
void LOCAL DrawDraggingRect(int type, HDC hDC, POINT pt);
void LOCAL UpdateScale(int type, POINT pt);
void LOCAL CalcScaleParms(SIZE wpgsp, RECT tr, LPSCALE lps);
